--[[
	Global BaleCounter for FS17
	
	Author: TCoGaming
	Date: 22/02/2017
]]--


BaleCounter = {};

local bc_directory = g_currentModDirectory;

function BaleCounter.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(Baler, specializations);
end;


function BaleCounter:load(xmlFile)
	self.currentBales = 0;
	self.totalBales = 0;
	
	self.xPos = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.BaleCounter#posX"), 0.8265);
	self.yPos = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.BaleCounter#posY"), 0.223);

	self.hud = Overlay:new("BaleCounter", Utils.getFilename("BaleCounter_hud.dds", bc_directory), self.xPos, self.yPos, 0.175, 0.035525);
	
	self.dirtyFlag = self:getNextDirtyFlag();
	self.isDirty = true;
end;

function BaleCounter:delete()
end;

function BaleCounter.dropBale(self, baleIndex)
	if self.currentBales ~= nil and self.totalBales ~= nil then
		self.currentBales = self.currentBales + 1;
		self.totalBales   = self.totalBales + 1;
		self.isDirty      = true;
	end;
end;

function BaleCounter:mouseEvent(posX, posY, isDown, isUp, button)
end;

function BaleCounter:keyEvent(unicode, sym, modifier, isDown)
end;

function BaleCounter:update(dt)
	if self.currentBales > 0 then
		if InputBinding.hasEvent(InputBinding.reset) then
			self.currentBales = 0;
			self.isDirty      = true;
		end;
	end;
end;

function BaleCounter:updateTick(dt)
	if self.isDirty then
		self:raiseDirtyFlags(self.dirtyFlag);
		self.isDirty = false;
	end;
end;

function BaleCounter:draw()
	local x = self.xPos + 0.0;
	local y = self.yPos + 0.0025;
	
	self.hud:render();
	if self.currentBales > 0 then
		g_currentMission:addHelpButtonText(("Counter Reset"), InputBinding.reset);
	end;
	setTextAlignment(RenderText.ALIGN_RIGHT);

	
	setTextColor(1, 1, 1, 1);
    renderText(x + 0.073, y + 0.008, 0.018, tostring(self.currentBales));
	renderText(x + 0.156, y + 0.008, 0.018, tostring(self.totalBales));
	
end;

function BaleCounter:readStream(streamId, connection)
	self.currentBales = streamReadFloat32(streamId);
	self.totalBales   = streamReadFloat32(streamId);
end;

function BaleCounter:writeStream(streamId, connection)
	streamWriteFloat32(streamId, self.currentBales);
	streamWriteFloat32(streamId, self.totalBales);
end;

function BaleCounter:readUpdateStream(streamId, timestamp, connection)
    if connection:getIsServer() then
        if streamReadBool(streamId) then
			self.currentBales = streamReadFloat32(streamId);
			self.totalBales = streamReadFloat32(streamId);
        end;
    end;
end;

function BaleCounter:writeUpdateStream(streamId, connection, dirtyMask)
    if not connection:getIsServer() then
        if streamWriteBool(streamId, bitAND(dirtyMask, self.dirtyFlag) ~= 0) then
			streamWriteFloat32(streamId, self.currentBales);
			streamWriteFloat32(streamId, self.totalBales);
        end;
    end;
end;

function BaleCounter:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	if (not resetVehicles) then
		self.totalBales = Utils.getNoNil(getXMLInt(xmlFile, key.."#totalBales"), 0);
		self.currentBales = Utils.getNoNil(getXMLInt(xmlFile, key.."#currentBales"), 0);
	end;
	
	return BaseMission.VEHICLE_LOAD_OK;
end;

function BaleCounter:getSaveAttributesAndNodes(nodeIdent)
	local attributes = 'totalBales="'..tostring(self.totalBales)..'" currentBales="'..tostring(self.currentBales)..'"';
	local nodes = nil;
	
	return attributes, nodes;
end;

Baler.dropBale = Utils.appendedFunction(BaleCounter.dropBale, Baler.dropBale);